@@ -341,17 +341,6 @@ CREATE OR REPLACE FUNCTION logp(molecule)
   COST 1;
 ALTER FUNCTION logp(molecule) OWNER TO postgres;
 
--- Function: migrate_molecule(bytea)
-
--- DROP FUNCTION migrate_molecule(bytea);
-
-CREATE OR REPLACE FUNCTION migrate_molecule(bytea)
-  RETURNS molecule AS
-'libpgchem', 'pgchem_molecule_to_new_molecule'
-  LANGUAGE 'c' IMMUTABLE STRICT
-  COST 1;
-ALTER FUNCTION migrate_molecule(bytea) OWNER TO postgres;
-
 -- Function: molecule_contained_in(molecule, molecule)
 
 -- DROP FUNCTION molecule_contained_in(molecule, molecule);
