@@ -1,7 +1,7 @@
 /**********************************************************************
  * functions.sql native chemistry handling functions SQL stubs
  *
- * Copyright (c) 2004,2008 by Ernst-G. Schmid
+ * Copyright (c) 2004,2010 by Ernst-G. Schmid
  *
  * This file is part of the pgchem::tigress project.
  * For more information, see
@@ -56,7 +56,7 @@ CREATE OR REPLACE FUNCTION inchi(molecule)
 'libpgchem', 'pgchem_molecule_to_inchi'
   LANGUAGE 'c' IMMUTABLE STRICT;
 
-CREATE OR REPLACE FUNCTION canonical_smiles(molecule)
+CREATE OR REPLACE FUNCTION canonical_smiles(molecule, boolean)
   RETURNS text AS
 'libpgchem', 'pgchem_molecule_to_canonical_smiles'
   LANGUAGE 'c' IMMUTABLE STRICT;
@@ -203,11 +203,6 @@ CREATE OR REPLACE FUNCTION PSA(molecule)
 'libpgchem', 'pgchem_PSA'
   LANGUAGE 'c' IMMUTABLE STRICT;
 
-CREATE OR REPLACE FUNCTION migrate_molecule(bytea)
-  RETURNS molecule AS
-'libpgchem','pgchem_molecule_to_new_molecule'
-  LANGUAGE 'c' IMMUTABLE STRICT;
-
 CREATE OR REPLACE FUNCTION SMARTSmatch(text, molecule)
   RETURNS boolean AS
 'libpgchem', 'pgchem_smartsfilter'
