@@ -1,7 +1,7 @@
 /**********************************************************************
  * pgchem_setup.sql unified type, operator and function setup file for pgchem GiST
  *
- * Copyright (c) 2004,2009 by Ernst-G. Schmid
+ * Copyright (c) 2004,2010 by Ernst-G. Schmid
  *
  * This file is part of the pgchem::tigress project.
  * For more information, see
@@ -235,7 +235,7 @@ CREATE OR REPLACE FUNCTION inchi(molecule)
 'libpgchem', 'pgchem_molecule_to_inchi'
   LANGUAGE 'c' IMMUTABLE STRICT;
 
-CREATE OR REPLACE FUNCTION canonical_smiles(molecule)
+CREATE OR REPLACE FUNCTION canonical_smiles(molecule,boolean)
   RETURNS text AS
 'libpgchem', 'pgchem_molecule_to_canonical_smiles'
   LANGUAGE 'c' IMMUTABLE STRICT;
@@ -382,11 +382,6 @@ CREATE OR REPLACE FUNCTION PSA(molecule)
 'libpgchem', 'pgchem_PSA'
   LANGUAGE 'c' IMMUTABLE STRICT;
 
-CREATE OR REPLACE FUNCTION migrate_molecule(bytea)
-  RETURNS molecule AS
-'libpgchem','pgchem_molecule_to_new_molecule'
-  LANGUAGE 'c' IMMUTABLE STRICT;
-
 CREATE OR REPLACE FUNCTION SMARTSmatch(text, molecule)
   RETURNS boolean AS
 'libpgchem', 'pgchem_smartsfilter'
