@@ -1085,7 +1085,7 @@ pgchem_molecule_to_smiles (PG_FUNCTION_ARGS)
   int len;
 
   tmpSmiles =
-    ob_mol_to_smiles (MFPTR (arg_molecule), omit_iso_and_chiral_markings ? 1 : 0);
+    ob_smiles_to_smiles (SMIPTR (arg_molecule), omit_iso_and_chiral_markings ? 1 : 0);
 				
   if(tmpSmiles == NULL) {
               goto smiles_fail;
@@ -1119,10 +1119,11 @@ pgchem_molecule_to_canonical_smiles (PG_FUNCTION_ARGS)
   char *tmpSmiles=NULL;
   text *retval;
   MOLECULE *arg_molecule = PG_GETARG_MOLECULE_P (0);
+  bool omit_iso_and_chiral_markings = PG_GETARG_BOOL (1);
   int len;
 
   tmpSmiles =
-    ob_mol_to_canonical_smiles (MFPTR (arg_molecule));
+    ob_smiles_to_canonical_smiles (SMIPTR (arg_molecule), omit_iso_and_chiral_markings ? 1 : 0);
 				
   if(tmpSmiles == NULL) {
               goto smiles_fail;
@@ -1964,7 +1965,10 @@ pgchem_smartsfilter (PG_FUNCTION_ARGS)
 
   strncat (tmpSMARTS, VARDATA (arg_smarts), smarts_string_len);
   
-  match = ob_SSS_SMARTS_native_bin (tmpSMARTS, ANCPTR(arg_molecule));
+  if(strstr(tmpSMARTS,"@")!=NULL || strstr(tmpSMARTS,"/")!=NULL || strstr(tmpSMARTS,"\\")!=NULL)
+    match = ob_SSS_SMARTS_native (tmpSMARTS, SMIPTR(arg_molecule));
+    else
+    match = ob_SSS_SMARTS_native_bin (tmpSMARTS, ANCPTR(arg_molecule));
   
   if(match<0) elog (ERROR, "Invalid SMARTS pattern: %s",tmpSMARTS);
 
@@ -1987,6 +1991,9 @@ pgchem_smartsfilter_count (PG_FUNCTION_ARGS)
 
   strncat (tmpSMARTS, VARDATA (arg_smarts), smarts_string_len);
 
+if(strstr(tmpSMARTS,"@")!=NULL || strstr(tmpSMARTS,"/")!=NULL || strstr(tmpSMARTS,"\\")!=NULL)
+    retval = ob_SSS_SMARTS_native_count (tmpSMARTS, SMIPTR(arg_molecule));
+else
   retval = ob_SSS_SMARTS_native_count_bin (tmpSMARTS, ANCPTR(arg_molecule));
   
   if(retval<0) elog (ERROR, "Invalid SMARTS pattern: %s",tmpSMARTS);
