@@ -25,7 +25,7 @@
 //static char bzhash[MOLHASHSZ];
 //static bool inited = false;
 
-Datum pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS);
+//Datum pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS);
 Datum molecule_in (PG_FUNCTION_ARGS);
 Datum molecule_in_text (PG_FUNCTION_ARGS);
 Datum molecule_in_varchar (PG_FUNCTION_ARGS);
@@ -294,7 +294,7 @@ new_molecule (char *smiles, char *molfile)
   char *aidata = NULL;
   uint32 ancsize = 0;
   
-  ancillarydata = ob_lyophilize_molecule(molfile);
+  ancillarydata = ob_lyophilize_molecule(smiles);
   
   if(ancillarydata == NULL) {
       elog (ERROR, "Molecule generation failed! Offender was :\n %s",molfile);
@@ -327,7 +327,7 @@ new_molecule (char *smiles, char *molfile)
   
   memcpy(ANCPTR(result), aidata, ancsize);
 
-  inchikey = ob_molfile_to_inchikey (molfile);
+  inchikey = ob_smiles_to_inchikey (smiles);
   
   //printf("%s\n",inchi);
   //printf("%s\n",smiles);
@@ -433,7 +433,7 @@ static MOLECULE *make_molecule(char *raw_input, int size) {
       }  else if (!strlen(smiles)) {
           elog (WARNING, "SMILES generation failed! Trying fallback...");
           free (smiles);
-           smiles = ob_mol_to_canonical_smiles (input);
+           smiles = ob_mol_to_canonical_smiles (input,0);
             if(smiles == NULL) {
                 elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",input);
             } else if (!strlen(smiles)) {
@@ -462,7 +462,7 @@ static MOLECULE *make_molecule(char *raw_input, int size) {
       }  else if (!strlen(smiles)) {
           elog (WARNING, "SMILES generation failed! Trying fallback...");
           free (smiles);
-           smiles = ob_mol_to_canonical_smiles (input);
+           smiles = ob_mol_to_canonical_smiles (input,0);
             if(smiles == NULL) {
                 elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",input);
             } else if (!strlen(smiles)) {
@@ -498,7 +498,7 @@ static MOLECULE *make_molecule(char *raw_input, int size) {
       }  else if (!strlen(smiles)) {
           elog (WARNING, "SMILES generation failed! Trying fallback...");
           free (smiles);
-           smiles = ob_mol_to_canonical_smiles (input);
+           smiles = ob_mol_to_canonical_smiles (input,0);
             if(smiles == NULL) {
                 elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",input);
             } else if (!strlen(smiles)) {
@@ -544,7 +544,7 @@ static MOLECULE *make_molecule(char *raw_input, int size) {
 * Convert an old pgchem::tigress bytea molecule to a new one of type molecule
 */
 
-PG_FUNCTION_INFO_V1 (pgchem_molecule_to_new_molecule);
+/*PG_FUNCTION_INFO_V1 (pgchem_molecule_to_new_molecule);
 
 Datum
 pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
@@ -575,12 +575,6 @@ pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
   *endptr = 0x0;
 
   sizemf = strlen (molfile) + 1;
-  
-  ancillarydata = ob_lyophilize_molecule(molfile);
-  
-  if(ancillarydata == NULL) elog (ERROR, "Molecule generation failed! Offender was :\n %s",molfile);
-  
-  ancsize = *(unsigned int*) ancillarydata;
 
   smiles = ob_mol_to_smiles (molfile,0);
   
@@ -589,7 +583,7 @@ pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
       }  else if (!strlen(smiles)) {
           elog (WARNING, "SMILES generation failed! Trying fallback...");
           free (smiles);
-           smiles = ob_mol_to_canonical_smiles (molfile);
+           smiles = ob_mol_to_canonical_smiles (molfile,0);
             if(smiles == NULL) {
                 elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
             } else if (!strlen(smiles)) {
@@ -601,6 +595,13 @@ pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
       }  
 
   sizesmi = strlen (smiles) + 1;
+  
+  ancillarydata = ob_lyophilize_molecule(smiles);
+  
+  ancsize = *(unsigned int*) ancillarydata;
+  
+  if(ancillarydata == NULL) 
+      elog (ERROR, "Molecule generation failed! Offender was :\n %s",molfile);
 
   totalsize = CALCDATASZ (sizemf, sizesmi, ancsize);
 
@@ -672,7 +673,7 @@ pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
   else if (ob_SSS_SMARTS_native (BZSMI, smiles) != 0)
     {
       result->nobz = false;
-    }*/
+    }
 
   pfree (molfile);
 
@@ -681,7 +682,7 @@ pgchem_molecule_to_new_molecule (PG_FUNCTION_ARGS)
   SET_VARSIZE (result,totalsize);
 
   PG_RETURN_MOLECULE_P (result);
-}
+}*/
 
 /*
 * Convert a molecule in text form (V2000, SMILES, InChI) into a molecule
@@ -746,11 +747,11 @@ molecule_out (PG_FUNCTION_ARGS)
   //int i;
   //unsigned int *arr = (unsigned int*) EFAPTR(molecule);
 
-  char *result = (char *) palloc (molecule->sizemf);
+  char *result = (char *) palloc (molecule->sizesmi);
   
-  memset(result,0x0,molecule->sizemf);
+  memset(result,0x0,molecule->sizesmi);
 
-  strncpy (result, MFPTR(molecule), molecule->sizemf);
+  strncpy (result, SMIPTR(molecule), molecule->sizesmi);
   
   //for(i=0;i<arr[0];i++) printf("%d ",arr[i]);
   //printf("\n");
@@ -878,24 +879,13 @@ pgchem_strip_salts (PG_FUNCTION_ARGS)
   MOLECULE *arg_molecule = PG_GETARG_MOLECULE_P (0);
   bool neutralize_residue = PG_GETARG_BOOL (1);
 
-  molfile = ob_strip_salts (MFPTR (arg_molecule), neutralize_residue ? 1 : 0);
+  smiles = ob_strip_salts (SMIPTR (arg_molecule), neutralize_residue ? 1 : 0);
   
-  smiles = ob_mol_to_smiles (molfile,0);
+  molfile = ob_smiles_to_mol (smiles);
   
-  if(smiles == NULL || !strlen(smiles)) {
-         elog (ERROR, "SMILES generation failed! Offender was :\n %s",molfile);
-      }  else if (!strlen(smiles)) {
-          elog (WARNING, "SMILES generation failed! Trying fallback...");
-          free (smiles);
-           smiles = ob_mol_to_canonical_smiles (molfile);
-            if(smiles == NULL) {
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-            } else if (!strlen(smiles)) {
-                free(smiles);
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-           }  
-           elog (WARNING, "Fallback OK"); 
-      }
+  if(molfile == NULL || !strlen(molfile)) {
+         elog (ERROR, "Molfile generation failed! Offender was :\n %s",smiles);
+      } 
    
   //efa_array = ob_efa_array(smiles);           
 
@@ -924,26 +914,15 @@ pgchem_add_hydrogens (PG_FUNCTION_ARGS)
   bool polaronly = PG_GETARG_BOOL (1);
   bool correct4PH = PG_GETARG_BOOL (2);
 
-  molfile =
-    ob_add_hydrogens (MFPTR (arg_molecule),
+  smiles =
+    ob_add_hydrogens (SMIPTR (arg_molecule),
 		      polaronly ? 1 : 0, correct4PH ? 1 : 0);
 
-  smiles = ob_mol_to_smiles (molfile,0);
+  molfile = ob_smiles_to_mol (smiles);
   
-  if(smiles == NULL || !strlen(smiles)) {
-         elog (ERROR, "SMILES generation failed! Offender was :\n %s",molfile);
-      }  else if (!strlen(smiles)) {
-          elog (WARNING, "SMILES generation failed! Trying fallback...");
-          free (smiles);
-           smiles = ob_mol_to_canonical_smiles (molfile);
-            if(smiles == NULL) {
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-            } else if (!strlen(smiles)) {
-                free(smiles);
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-           }  
-           elog (WARNING, "Fallback OK"); 
-      }  
+   if(molfile == NULL || !strlen(molfile)) {
+         elog (ERROR, "Molfile generation failed! Offender was :\n %s",smiles);
+      } 
 
   //efa_array = ob_efa_array(smiles);           
 
@@ -971,27 +950,15 @@ pgchem_remove_hydrogens (PG_FUNCTION_ARGS)
   MOLECULE *arg_molecule = PG_GETARG_MOLECULE_P (0);
   bool nonpolaronly = PG_GETARG_BOOL (1);
 
-  molfile =
-    ob_delete_hydrogens (MFPTR (arg_molecule),
+ smiles =
+    ob_delete_hydrogens (SMIPTR (arg_molecule),
 			 nonpolaronly ? 1 : 0);
 
- smiles = ob_mol_to_smiles (molfile,0);
+ molfile = ob_smiles_to_mol (smiles);
   
-  if(smiles == NULL || !strlen(smiles)) {
-         elog (ERROR, "SMILES generation failed! Offender was :\n %s",molfile);
-      }  else if (!strlen(smiles)) {
-          elog (WARNING, "SMILES generation failed! Trying fallback...");
-          free (smiles);
-           smiles = ob_mol_to_canonical_smiles (molfile);
-            if(smiles == NULL) {
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-            } else if (!strlen(smiles)) {
-                free(smiles);
-                elog (ERROR, "SMILES generation finally failed! Offender was :\n %s",molfile);
-           }  
-           elog (WARNING, "Fallback OK"); 
-      }  
-
+   if(molfile == NULL || !strlen(molfile)) {
+         elog (ERROR, "Molfile generation failed! Offender was :\n %s",smiles);
+      } 
   //efa_array = ob_efa_array(smiles);           
 
   retval = new_molecule (smiles, molfile);
