@@ -93,7 +93,7 @@ ob_mol_to_smiles (char *molfile, int omit_iso_and_chiral_markings)
 }
 
 extern "C" char *
-ob_mol_to_canonical_smiles (char *molfile)
+ob_mol_to_canonical_smiles (char *molfile, int omit_iso_and_chiral_markings)
 {
   OBMol mol;
   OBConversion conv;
@@ -106,6 +106,82 @@ ob_mol_to_canonical_smiles (char *molfile)
   conv.SetInAndOutFormats ("MDL", "CAN");
   conv.AddOption ("n", OBConversion::OUTOPTIONS);
   //conv.AddOption ("c", OBConversion::OUTOPTIONS);
+  if (omit_iso_and_chiral_markings != 0)
+    {
+      conv.AddOption ("i", OBConversion::OUTOPTIONS);
+    }
+
+  conv.Read (&mol, &molstream);
+
+  if (mol.Empty ())
+    return NULL;
+
+  conv.Write (&mol, &smilesstream);
+
+  outstring = smilesstream.str ();
+
+  outstring = outstring.substr (0, outstring.length () - 1);
+
+  tmpSmiles = strdup (outstring.c_str ());
+
+  return (tmpSmiles);
+}
+
+extern "C" char *
+ob_smiles_to_smiles (char *smiles, int omit_iso_and_chiral_markings)
+{
+  OBMol mol;
+  OBConversion conv;
+  string tmpStr (smiles);
+  string outstring;
+  istringstream molstream (tmpStr);
+  ostringstream smilesstream;
+  char *tmpSmiles;
+
+  conv.SetInAndOutFormats ("SMI", "SMI");
+  conv.AddOption ("n", OBConversion::OUTOPTIONS);
+  
+  if (omit_iso_and_chiral_markings != 0)
+    {
+      conv.AddOption ("i", OBConversion::OUTOPTIONS);
+    }
+
+  conv.Read (&mol, &molstream);
+
+  if (mol.Empty ())
+    return NULL;
+
+  conv.Write (&mol, &smilesstream);
+
+  outstring = smilesstream.str ();
+
+  //outstring = outstring.substr (0, outstring.length ()-1);
+
+  tmpSmiles = strdup (outstring.c_str ());
+  
+  //printf("Orig: %s\n",tmpSmiles);
+
+  return (tmpSmiles);
+}
+
+extern "C" char *
+ob_smiles_to_canonical_smiles (char *smiles, int omit_iso_and_chiral_markings)
+{
+  OBMol mol;
+  OBConversion conv;
+  string tmpStr (smiles);
+  string outstring;
+  istringstream molstream (tmpStr);
+  ostringstream smilesstream;
+  char *tmpSmiles;
+
+  conv.SetInAndOutFormats ("SMI", "CAN");
+  conv.AddOption ("n", OBConversion::OUTOPTIONS);
+  //conv.AddOption ("c", OBConversion::OUTOPTIONS);
+  if (omit_iso_and_chiral_markings != 0)
+    {
+      conv.AddOption ("i", OBConversion::OUTOPTIONS);
+    }
 
   conv.Read (&mol, &molstream);
 
@@ -588,17 +664,17 @@ ob_3D (char *molfile)
 }
 
 extern "C" char *
-ob_add_hydrogens (char *molfile, int polaronly, int correct4PH)
+ob_add_hydrogens (char *smiles, int polaronly, int correct4PH)
 {
   OBMol mol;
   OBConversion conv;
-  string tmpStr (molfile);
+  string tmpStr (smiles);
   string outstring;
   istringstream molstream1 (tmpStr);
   ostringstream molstream2;
   char *tmpMolfile;
 
-  conv.SetInAndOutFormats ("MDL", "MDL");
+  conv.SetInAndOutFormats ("SMI", "SMI");
 
   conv.Read (&mol, &molstream1);
 
@@ -624,17 +700,17 @@ ob_add_hydrogens (char *molfile, int polaronly, int correct4PH)
 }
 
 extern "C" char *
-ob_delete_hydrogens (char *molfile, int nonpolaronly)
+ob_delete_hydrogens (char *smiles, int nonpolaronly)
 {
   OBMol mol;
   OBConversion conv;
-  string tmpStr (molfile);
+  string tmpStr (smiles);
   string outstring;
   istringstream molstream1 (tmpStr);
   ostringstream molstream2;
   char *tmpMolfile;
 
-  conv.SetInAndOutFormats ("MDL", "MDL");
+  conv.SetInAndOutFormats ("SMI", "SMI");
 
   conv.Read (&mol, &molstream1);
 
@@ -713,12 +789,12 @@ ob_strip_salts (char *molfile, int neutralize_residue)
 } */
 
 extern "C" char *
-ob_strip_salts (char *molfile, int neutralize_residue)
+ob_strip_salts (char *smiles, int neutralize_residue)
 {
   OBAtom atom;
   OBMol mol, largestFragment;
   OBConversion conv;
-  string tmpStr (molfile);
+  string tmpStr (smiles);
   string outstring;
   istringstream molstream1 (tmpStr);
   ostringstream molstream2;
@@ -727,7 +803,7 @@ ob_strip_salts (char *molfile, int neutralize_residue)
   char *tmpMolfile;
   int max = 0;
 
-  conv.SetInAndOutFormats ("MDL", "MDL");
+  conv.SetInAndOutFormats ("SMI", "SMI");
 
   conv.Read (&mol, &molstream1);
 
@@ -1414,16 +1490,16 @@ ob_SSS_SMARTS_native_bin (const char *smarts_pattern, char *serializedInput)
 }
 
 extern "C" int
-ob_SSS_SMARTS_native (const char *smarts_pattern, char *molfile)
+ob_SSS_SMARTS_native (const char *smarts_pattern, char *smiles)
 {
   OBMol mol;
   OBSmartsPattern sp;
   OBConversion conv;
-  string tmpStr (molfile);
+  string tmpStr (smiles);
   istringstream molstream (tmpStr);
   bool match, mol_ok;
 
-  conv.SetInFormat ("MDL");
+  conv.SetInFormat ("SMI");
 
   conv.Read (&mol, &molstream);
 
@@ -1473,18 +1549,18 @@ ob_SSS_SMARTS_native_count_bin (const char *smarts_pattern, char *serializedInpu
 }
 
 extern "C" int
-ob_SSS_SMARTS_native_count (const char *smarts_pattern, char *molfile)
+ob_SSS_SMARTS_native_count (const char *smarts_pattern, char *smiles)
 {
   OBMol mol;
   OBConversion conv;
   OBSmartsPattern sp;
-  string tmpStr (molfile);
+  string tmpStr (smiles);
   istringstream molstream (tmpStr);
   //vector <vector<int> > maplist;
   unsigned int matchcount = 0;
   
 
-  conv.SetInFormat ("MDL");
+  conv.SetInFormat ("SMI");
 
   conv.Read (&mol, &molstream);
 
@@ -1790,17 +1866,18 @@ static bool ob_rehydrate_molecule(OBBase* pOb, char *serializedInput)
     //mol.SetFlags(*(int*)intptr);  
       
     mol.SetAromaticPerceived();
-    mol.SetKekulePerceived();  
+    mol.SetKekulePerceived();
+    mol.SetChiralityPerceived();  
 
     return(true);
   }
   
-extern "C" char *ob_lyophilize_molecule(char* molfile) {
+extern "C" char *ob_lyophilize_molecule(char* smiles) {
       OBMol mol;
       OBConversion conv;
-      string tmpStr (molfile);
+      string tmpStr (smiles);
       istringstream molstream (tmpStr);
-      conv.SetInFormat("MDL");
+      conv.SetInFormat("SMI");
       conv.Read (&mol, &molstream);
       if(mol.Empty()) return NULL;
       unsigned int numatoms = mol.NumAtoms();
@@ -1811,7 +1888,7 @@ extern "C" char *ob_lyophilize_molecule(char* molfile) {
       _ATOM *atomptr;
       _BOND *bondptr;
       
-      mol.Kekulize();
+      //mol.Kekulize();
       
       memset(retval,0x0,totalsize);
       
